

ttcal - calendar operations
===========================

.. image:: https://travis-ci.org/datakortet/ttcal.svg?branch=master
    :target: https://travis-ci.org/datakortet/ttcal

.. image:: https://coveralls.io/repos/github/datakortet/ttcal/badge.svg?branch=master
    :target: https://coveralls.io/github/datakortet/ttcal

.. image:: https://gitlab.com/norsktest/ttcal/badges/master/pipeline.svg
   :target: https://gitlab.com/norsktest/ttcal/commits/master
   :alt: pipeline status

.. image:: https://img.shields.io/badge/docs-darkgreen.svg
   :target: https://norsktest.gitlab.io/ttcal
   :alt: documentation

.. image:: https://codecov.io/gl/norsktest/ttcal/branch/master/graph/badge.svg?token=AU6BBD04LY
  :target: https://codecov.io/gl/norsktest/ttcal



